# AdditionalSpecialDesignationsResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**street_special_desig_code** | [**AdditionalSpecialDesignationCodeResponse**](AdditionalSpecialDesignationCodeResponse.md) |  | 
**street_special_desig_code_string** | **str** |  | [optional] 
**special_desig_location_text** | **str** |  | [optional] 
**special_desig_description** | **str** |  | [optional] 
**special_desig_start_time** | **float** |  | [optional] 
**special_desig_end_time** | **float** |  | [optional] 
**special_desig_periodicity_code** | **AllOfAdditionalSpecialDesignationsResponseSpecialDesigPeriodicityCode** |  | [optional] 
**special_desig_periodicity_code_string** | **str** |  | [optional] 
**asd_coordinate_geometry** | **AllOfAdditionalSpecialDesignationsResponseAsdCoordinateGeometry** |  | [optional] 
**whole_road** | **bool** |  | [optional] 
**special_desig_start_date** | **datetime** |  | [optional] 
**special_desig_end_date** | **datetime** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

